@@ -18,5 +18,4 @@ INFLUX_PROXY_LOG = "/var/log/influx_proxy"
 LOG_PATH = os.getenv('LOG_PATH', INFLUX_PROXY_LOG)
 MONITORING_ELASTIC_NODE = os.getenv('MONITORING_ELASTIC_NODE', '10.200.129.60')
 SERVICE_NAME = os.getenv('SERVICE_NAME', 'influx_proxy')
-LOG_LEVEL = "DEBUG"
-
+LOG_LEVEL = os.getenv('LOG_LEVEL', 'INFO')
